@@ -36,7 +36,7 @@
  * @include: geocode-glib/geocode-glib.h
  *
  * Contains functions for geocoding using the
- * <ulink url="http://http://wiki.openstreetmap.org/wiki/Nominatim">OSM Nominatim APIs</ulink>
+ * <ulink url="http://wiki.openstreetmap.org/wiki/Nominatim">OSM Nominatim APIs</ulink>
  **/
 
 struct _GeocodeForwardPrivate {
@@ -343,15 +343,15 @@ get_search_query_for_params (GeocodeForward *forward,
 
 	/* Prepare the query parameters */
 	ht = _geocode_glib_dup_hash_table (forward->priv->ht);
-	g_hash_table_insert (ht, "format", "json");
-	g_hash_table_insert (ht, "email", "zeeshanak@gnome.org");
-	g_hash_table_insert (ht, "addressdetails", "1");
+	g_hash_table_insert (ht, (gpointer) "format", (gpointer) "json");
+	g_hash_table_insert (ht, (gpointer) "email", (gpointer) "zeeshanak@gnome.org");
+	g_hash_table_insert (ht, (gpointer) "addressdetails", (gpointer) "1");
 
 	lang = NULL;
 	if (g_hash_table_lookup (ht, "accept-language") == NULL) {
 		lang = _geocode_object_get_lang ();
 		if (lang)
-			g_hash_table_insert (ht, "accept-language", lang);
+			g_hash_table_insert (ht, (gpointer) "accept-language", lang);
 	}
 
         location = g_strdup (g_hash_table_lookup (ht, "location"));
@@ -364,12 +364,12 @@ get_search_query_for_params (GeocodeForward *forward,
         if (location != NULL) {
 	        /* Prepare the search term */
                 search_term = soup_uri_encode (location, NULL);
-                uri = g_strdup_printf ("http://nominatim.openstreetmap.org/search?q=%s&limit=%u&%s",
+                uri = g_strdup_printf ("http://nominatim.gnome.org/search?q=%s&limit=%u&%s",
                                        search_term, forward->priv->answer_count, params);
                 g_free (search_term);
                 g_free (location);
         } else {
-                uri = g_strdup_printf ("http://nominatim.openstreetmap.org/search?limit=1&%s",
+                uri = g_strdup_printf ("http://nominatim.gnome.org/search?limit=1&%s",
                                        params);
         }
 	g_free (params);
